`html2text` was originally written by Aaron Swartz.

The AUTHORS/Contributors are (and/or have been):


* Aaron Swartz


* Yariv Barkan


* Alex Musayev


* Matěj Cepl


* Stefano Rivera


* Alireza Savand <[alireza.savand@gmail.com](mailto:alireza.savand@gmail.com)>


* Ivan Gromov <[summer.is.gone@gmail.com](mailto:summer.is.gone@gmail.com)>


* Jocelyn Delalande <[jdelalande@oasiswork.fr](mailto:jdelalande@oasiswork.fr)>


* Matt Dorn <[matt.dorn@gmail.com](mailto:matt.dorn@gmail.com)>


* Miguel Tavares <[mgontav@gmail.com](mailto:mgontav@gmail.com)>


* Scott Blackburn <[scott@skipflag.com](mailto:scott@skipflag.com)>


* Peter Wu <[peter@lekensteyn.nl](mailto:peter@lekensteyn.nl)>


* Arjoonn Sharma <gh: theSage21>


* Ali Mohammad <gh: alawibaba>


* Albert Berger <gh: nbdsp>


* Etienne Millon <[me@emillon.org](mailto:me@emillon.org)>


* John C F <gh: critiqjo>


* Mikhail Melnik <[by.zumzoom@gmail.com](mailto:by.zumzoom@gmail.com)>


* Andres Rey


* Ciprian Miclaus


* Toshihiro Kamiya <[kamiya@mbj.nifty.com](mailto:kamiya@mbj.nifty.com)>


* Matt Dennewitz <[mattdennewitz@gmail.com](mailto:mattdennewitz@gmail.com)>


* Jonathan Sundqvist <[sundqvist.jonathan@gmail.com](mailto:sundqvist.jonathan@gmail.com)>


* Simon Meers <gh: DrMeers>


* Kurt McKee <[contactme@kurtmckee.org](mailto:contactme@kurtmckee.org)>


* Germain Z. <gh: GermainZ>


* Jacek Kołodziej <[kolodziejj@gmail.com](mailto:kolodziejj@gmail.com)>


* Jonathan Vanasco <[jonathan@findmeon.com](mailto:jonathan@findmeon.com)>


* Jon Dufresne <[jon.dufresne@gmail.com](mailto:jon.dufresne@gmail.com)>

Maintainer:


* Alireza Savand <[alireza.savand@gmail.com](mailto:alireza.savand@gmail.com)>
